@@ -66,6 +66,7 @@ import sun.util.resources.OpenListResourceBundle;
 public class LocaleNames_tk extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String metaValue_chr = "\u00e7eroki";
         final Object[][] data = new Object[][] {
             { "001", "D\u00fcn\u00fd\u00e4" },
             { "002", "Afrika" },
@@ -540,45 +541,46 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "ain", "a\u00fdn dili" },
             { "ale", "aleut dili" },
             { "alt", "g\u00fcnorta Alta\u00fd dili" },
-            { "ann", "Obolo dili" },
+            { "ann", "obolo dili" },
             { "anp", "angika dili" },
             { "arn", "mapu\u00e7e dili" },
             { "arp", "arapaho dili" },
-            { "ars", "Nejdi arap dili" },
+            { "ars", "nejdi arap dili" },
             { "asa", "asu dili" },
             { "ast", "asturi\u00fd dili" },
-            { "atj", "Atikamekw dili" },
+            { "atj", "atikamekw dili" },
             { "awa", "awadhi dili" },
             { "ban", "bali\u00fd dili" },
             { "bas", "basaa dili" },
             { "bem", "bemba dili" },
             { "bez", "bena dili" },
+            { "bgc", "har\u00fdanwi dili" },
             { "bho", "bhojpuri dili" },
             { "bin", "bini dili" },
             { "bla", "siksika dili" },
             { "brx", "bodo dili" },
             { "bug", "bugi\u00fd dili" },
             { "byn", "blin dili" },
-            { "cay", "Ka\u00fduga dili" },
+            { "cay", "ka\u00fduga dili" },
             { "ccp", "\u00e7akma dili" },
             { "ceb", "sebuan dili" },
             { "cgg", "kiga" },
             { "chk", "\u00e7uuk dili" },
             { "chm", "mari\u00fd dili" },
             { "cho", "\u00e7okto" },
-            { "chp", "\u00c7ipew\u00fdan dili" },
-            { "chr", "\u00e7eroki" },
+            { "chp", "\u00e7ipew\u00fdan dili" },
+            { "chr", metaValue_chr },
             { "chy", "\u015fa\u00fdenn dili" },
             { "ckb", "merkezi k\u00fcrt dili" },
-            { "clc", "\u00c7ilkotin dili" },
-            { "crg", "Mi\u00e7if dili" },
-            { "crj", "G\u00fcnorta-g\u00fcndogar kri dili" },
-            { "crk", "D\u00fczde\u00e7i kri dili" },
-            { "crl", "Demirgazyk-g\u00fcndogar kri dili" },
-            { "crm", "Los-kri dili" },
-            { "crr", "Karolina algonkin dili" },
+            { "clc", "\u00e7ilkotin dili" },
+            { "crg", "mi\u00e7if dili" },
+            { "crj", "g\u00fcnorta-g\u00fcndogar kri dili" },
+            { "crk", "d\u00fczde\u00e7i kri dili" },
+            { "crl", "demirgazyk-g\u00fcndogar kri dili" },
+            { "crm", "los-kri dili" },
+            { "crr", "karolina algonkin dili" },
             { "crs", "seselwa kreole-fransuz dili" },
-            { "csw", "Batgalyk kri dili" },
+            { "csw", "batgalyk kri dili" },
             { "dak", "dakota dili" },
             { "dar", "dargi dili" },
             { "dav", "taita dili" },
@@ -595,8 +597,8 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "ewo", "ewondo dili" },
             { "fil", "filippin dili" },
             { "fon", "fon dili" },
-            { "frc", "Fransuz dilini\u0148 kajun \u015fiwesi" },
-            { "frr", "Demirgazyk friz dili" },
+            { "frc", "fransuz dilini\u0148 kajun \u015fiwesi" },
+            { "frr", "demirgazyk friz dili" },
             { "fur", "friul dili" },
             { "gaa", "ga dili" },
             { "gez", "geez dili" },
@@ -605,17 +607,17 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "gsw", "nemes dili (\u015ewe\u00fdsari\u00fda)" },
             { "guz", "gusii dili" },
             { "gwi", "gwi\u00e7in dili" },
-            { "hai", "Ha\u00fdda dili" },
+            { "hai", "ha\u00fdda dili" },
             { "haw", "gawa\u00fd dili" },
-            { "hax", "G\u00fcnorta ha\u00fdda dili" },
+            { "hax", "g\u00fcnorta ha\u00fdda dili" },
             { "hil", "hiliga\u00fdnon dili" },
             { "hmn", "hmong dili" },
             { "hsb", "\u00fdokarky lu\u017eits dili" },
             { "hup", "hupa" },
-            { "hur", "Halkomelem dili" },
+            { "hur", "halkomelem dili" },
             { "iba", "iban dili" },
             { "ibb", "ibibio dili" },
-            { "ikt", "G\u00fcnorta-kanada iniktitut dili" },
+            { "ikt", "G\u00fcnorta Kanada iniktitut dili" },
             { "ilo", "iloko dili" },
             { "inh", "ingu\u015f dili" },
             { "jbo", "lojban dili" },
@@ -630,7 +632,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "kde", "makonde dili" },
             { "kea", "kabuwerdianu dili" },
             { "kfo", "koro dili" },
-            { "kgp", "Ka\u00fdngang dili" },
+            { "kgp", "ka\u00fdngang dili" },
             { "kha", "khasi dili" },
             { "khq", "ko\u00fdra-\u00e7ini dili" },
             { "kkj", "kako dili" },
@@ -645,16 +647,16 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "ksf", "bafia dili" },
             { "ksh", "keln dili" },
             { "kum", "kumyk dili" },
-            { "kwk", "Kwakwala dili" },
+            { "kwk", "kwakwala dili" },
             { "lad", "ladino dili" },
             { "lag", "langi dili" },
             { "lez", "lezgin dili" },
-            { "lil", "Lilluet dili" },
+            { "lil", "lilluet dili" },
             { "lkt", "lakota dili" },
             { "lou", "Luiziana kreol dili" },
             { "loz", "lozi dili" },
             { "lrc", "demirgazyk luri dili" },
-            { "lsm", "Sami\u00fda dili" },
+            { "lsm", "sami\u00fda dili" },
             { "lua", "luba-Lulua dili" },
             { "lun", "lunda dili" },
             { "luo", "luo dili" },
@@ -674,7 +676,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "mic", "mikmak dili" },
             { "min", "minangkabau dili" },
             { "mni", "manipuri dili" },
-            { "moe", "Innu-a\u00fdmun dili" },
+            { "moe", "innu-a\u00fdmun dili" },
             { "moh", "mogauk dili" },
             { "mos", "mossi dili" },
             { "mua", "mundang dili" },
@@ -696,20 +698,21 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "nso", "demirgazyk soto dili" },
             { "nus", "nuer dili" },
             { "nyn", "n\u00fdankole dili" },
-            { "ojb", "Demirgazyk-g\u00fcnbatar ojibwa dili" },
-            { "ojc", "Merkezi ojibwa dili" },
-            { "ojs", "Oji-kri dili" },
-            { "ojw", "G\u00fcnbatar ojibwa dili" },
-            { "oka", "Okanagan dili" },
+            { "ojb", "demirgazyk-g\u00fcnbatar ojibwa dili" },
+            { "ojc", "merkezi ojibwa dili" },
+            { "ojs", "oji-kri dili" },
+            { "ojw", "g\u00fcnbatar ojibwa dili" },
+            { "oka", "okanagan dili" },
             { "pag", "pangansinan dili" },
             { "pam", "kapampangan dili" },
             { "pap", "pap\u00fdamento dili" },
             { "pau", "palau dili" },
             { "pcm", "nigeri\u00fda-pijin dili" },
-            { "pis", "Pijin dili" },
-            { "pqm", "Malisit-Passamakwodi dili" },
+            { "pis", "pijin dili" },
+            { "pqm", "malisit-passamakwodi dili" },
             { "prg", "prussi\u00fda dili" },
             { "quc", "ki\u00e7e dili" },
+            { "raj", "rajastani dili" },
             { "rap", "rapanu\u00fd dili" },
             { "rar", "kuk dili" },
             { "rhg", "rohin\u00fda dili" },
@@ -728,7 +731,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "ses", "ko\u00fdraboro-senni dili" },
             { "shi", "tahelhit dili" },
             { "shn", "\u015fan dili" },
-            { "slh", "G\u00fcnorta Lu\u015futsid dili" },
+            { "slh", "g\u00fcnorta Lu\u015futsid dili" },
             { "sma", "g\u00fcnorta saam dili" },
             { "smj", "lule-saam dili" },
             { "smn", "inari-saam dili" },
@@ -736,23 +739,23 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "snk", "soninke dili" },
             { "srn", "sranan-tongo dili" },
             { "ssy", "saho dili" },
-            { "str", "Demirgazyk bogaz sali\u015f dili" },
+            { "str", "demirgazyk bogaz sali\u015f dili" },
             { "suk", "sukuma dili" },
             { "swb", "komor dili" },
             { "syr", "siri\u00fda dili" },
-            { "tce", "G\u00fcnorta Tut\u00e7one dili" },
+            { "tce", "g\u00fcnorta tut\u00e7one dili" },
             { "tem", "temne dili" },
             { "teo", "teso dili" },
             { "tet", "tetum dili" },
-            { "tgx", "Tagi\u015f dili" },
-            { "tht", "Taltan dili" },
+            { "tgx", "tagi\u015f dili" },
+            { "tht", "taltan dili" },
             { "tig", "tigre dili" },
             { "tlh", "klingon dili" },
-            { "tli", "Tlinkit dili" },
-            { "tok", "Toki Pona dili" },
+            { "tli", "tlinkit dili" },
+            { "tok", "toki pona dili" },
             { "tpi", "tok-pisin dili" },
             { "trv", "taroko dili" },
-            { "ttm", "Demirgazyk tut\u00e7one dili" },
+            { "ttm", "demirgazyk tut\u00e7one dili" },
             { "tum", "tumbuka dili" },
             { "tvl", "tuwalu dili" },
             { "twq", "tasawak dili" },
@@ -766,27 +769,27 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "wae", "walzer dili" },
             { "wal", "wola\u00fdta dili" },
             { "war", "wara\u00fd dili" },
-            { "wuu", "U hyta\u00fd dili" },
+            { "wuu", "u hyta\u00fd dili" },
             { "xal", "galmyk dili" },
             { "xog", "soga dili" },
             { "yav", "\u00fdangben dili" },
             { "ybb", "\u00fdemba dili" },
-            { "yrl", "Nhengatu dili" },
+            { "yrl", "nhengatu dili" },
             { "yue", "kanton dili" },
             { "zgh", "standart Marokko tamazight dili" },
             { "zun", "zuni dili" },
             { "zxx", "dil\u00e7ilige degi\u015fli mazmun \u00fdok" },
             { "zza", "zazaki dili" },
-            { "Adlm", "Adlam" },
+            { "Adlm", "adlam" },
             { "Arab", "Arap elipbi\u00fdi" },
             { "Aran", "Nastalik \u00fdazuwy" },
             { "Armn", "Ermeni elipbi\u00fdi" },
             { "Beng", "Bengal elipbi\u00fdi" },
             { "Bopo", "Bopomofo elipbi\u00fdi" },
             { "Brai", "Bra\u00fdl elipbi\u00fdi" },
-            { "Cakm", "\u00c7akma" },
+            { "Cakm", "\u00e7akma" },
             { "Cans", "Kanadany\u0148 \u00fderlilerini\u0148 bogunlaryny\u0148 bitewile\u015fdirilen ulgamy" },
-            { "Cher", "\u00c7eroki" },
+            { "Cher", metaValue_chr },
             { "Cyrl", "Kiril elipbi\u00fdi" },
             { "Deva", "Dewanagari elipbi\u00fdi" },
             { "Ethi", "Efiop elipbi\u00fdi" },
@@ -812,12 +815,12 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "Latn", "Latyn elipbi\u00fdi" },
             { "Mlym", "Mala\u00fdalam elipbi\u00fdi" },
             { "Mong", "Mongol elipbi\u00fdi" },
-            { "Mtei", "Me\u00fdte\u00fd Ma\u00fdek" },
+            { "Mtei", "me\u00fdte\u00fd-ma\u00fdek" },
             { "Mymr", "M\u00fdanma elipbi\u00fdi" },
-            { "Nkoo", "N\u2019Ko" },
-            { "Olck", "Ol \u00c7iki" },
+            { "Nkoo", "nko" },
+            { "Olck", "ol-\u00e7iki" },
             { "Orya", "Ori\u00fda elipbi\u00fdi" },
-            { "Rohg", "Hanifi" },
+            { "Rohg", "hanifi" },
             { "Sinh", "Singal elipbi\u00fdi" },
             { "Sund", "Sundanez \u00fdazuwy" },
             { "Syrc", "Siri\u00fda \u00fdazuwy" },
@@ -922,7 +925,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "type.nu.fullwide", "Doly gi\u0148likd\u00e4ki sanlar" },
             { "type.nu.romanlow", "Rim setir sanlary" },
             { "type.ca.gregorian", "Grigorian senenamasy" },
-            { "type.ca.islamic-tbla", "Hijri-kamary senenamasy (tablisaly, astronimi\u00fda e\u00fd\u00fdamy)" },
+            { "type.ca.islamic-tbla", "Hijri-kamary senenamasy (tablisaly, astronomik e\u00fd\u00fdam)" },
             { "type.ca.islamic-civil", "Hijri-kamary senenamasy (tablisaly, ra\u00fdat e\u00fd\u00fdamy)" },
             { "type.ca.islamic-umalqura", "Hijri-kamary senenamasy (Umm al-Kura)" },
             { "type.ca.ethiopic-amete-alem", "Efiopi\u00fda Amete Alem senenamasy" },
